@@ -1,11 +1,20 @@
 mod binance_all;
 mod binance_option;
 
+use std::collections::HashMap;
+
 use crypto_market_type::MarketType;
 
 use crate::{FundingRateMsg, OrderBookMsg, TradeMsg};
 
-use serde_json::Result;
+use serde_json::{Result, Value};
+
+pub(crate) fn extract_symbol(_market_type: MarketType, msg: &str) -> Option<String> {
+    let obj = serde_json::from_str::<HashMap<String, Value>>(msg).unwrap();
+    let data = obj.get("data").unwrap();
+    let symbol = data["s"].as_str().unwrap();
+    Some(symbol.to_string())
+}
 
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     if market_type == MarketType::EuropeanOption {
