@@ -48,6 +48,12 @@ struct WebsocketMsg<T: Sized> {
     time: i64,
 }
 
+pub(crate) fn extract_symbol(_market_type: MarketType, msg: &str) -> Option<String> {
+    let ws_msg = serde_json::from_str::<WebsocketMsg<Value>>(msg).unwrap();
+    let symbol = ws_msg.params.symbol.as_str();
+    Some(symbol.to_string())
+}
+
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     let ws_msg = serde_json::from_str::<WebsocketMsg<Vec<SpotTradeMsg>>>(msg)?;
     let symbol = ws_msg.params.symbol.as_str();
