@@ -46,9 +46,17 @@ struct OrderbookUpdate {
     extra: HashMap<String, Value>,
 }
 
+pub(crate) fn extract_symbol(_market_type_: MarketType, msg: &str) -> Option<String> {
+    let arr = serde_json::from_str::<Vec<Value>>(msg).unwrap();
+    let symbol = arr[arr.len() - 1].as_str().unwrap();
+    Some(symbol.to_string())
+}
+
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     let arr = serde_json::from_str::<Vec<Value>>(msg)?;
-    let symbol = arr[3].as_str().unwrap();
+    debug_assert_eq!(arr[2].as_str().unwrap(), "trade");
+    debug_assert_eq!(arr.len(), 4);
+    let symbol = arr[arr.len() - 1].as_str().unwrap();
     let pair = crypto_pair::normalize_pair(symbol, EXCHANGE_NAME).unwrap();
     let raw_trades: Vec<Vec<String>> = serde_json::from_value(arr[1].clone()).unwrap();
 
@@ -91,6 +99,9 @@ pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<Trad
 pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBookMsg>> {
     debug_assert_eq!(market_type, MarketType::Spot);
     let arr = serde_json::from_str::<Vec<Value>>(msg)?;
+    debug_assert_eq!(arr[arr.len() - 2].as_str().unwrap(), "book-25");
+    let symbol = arr[arr.len() - 1].as_str().unwrap().to_string();
+    let pair = crypto_pair::normalize_pair(&symbol, EXCHANGE_NAME).unwrap();
     let snapshot = arr[1].as_object().unwrap().contains_key("as");
 
     let parse_order = |raw_order: &[String]| -> Order {
@@ -105,110 +116,108 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
         }
     };
 
-    let orderbook = if snapshot {
-        debug_assert_eq!(arr[2].as_str().unwrap(), "book-25");
-        let symbol = arr[3].as_str().unwrap();
-        let pair = crypto_pair::normalize_pair(symbol, EXCHANGE_NAME).unwrap();
+    let orderbooks = if snapshot {
         let orderbook_snapshot = serde_json::from_value::<OrderbookSnapshot>(arr[1].clone())?;
-        let timestamp = if !orderbook_snapshot.asks.is_empty() {
-            (orderbook_snapshot.asks[0][2].parse::<f64>().unwrap() * 1000.0) as i64
-        } else if !orderbook_snapshot.bids.is_empty() {
-            (orderbook_snapshot.bids[0][2].parse::<f64>().unwrap() * 1000.0) as i64
-        } else {
-            panic!("{}", msg);
+
+        let timestamp = {
+            let mut timestamps: Vec<i64> = Vec::new();
+            for ask in orderbook_snapshot.asks.iter() {
+                let t = (ask[2].parse::<f64>().unwrap() * 1000.0) as i64;
+                timestamps.push(t);
+            }
+            for bid in orderbook_snapshot.bids.iter() {
+                let t = (bid[2].parse::<f64>().unwrap() * 1000.0) as i64;
+                timestamps.push(t);
+            }
+            if timestamps.is_empty() {
+                None
+            } else {
+                let max = *timestamps.iter().max().unwrap();
+                Some(max)
+            }
         };
 
-        OrderBookMsg {
-            exchange: EXCHANGE_NAME.to_string(),
-            market_type: MarketType::Spot,
-            symbol: symbol.to_string(),
-            pair,
-            msg_type: MessageType::L2Event,
-            timestamp,
-            asks: orderbook_snapshot
-                .asks
-                .iter()
-                .map(|x| parse_order(x))
-                .collect(),
-            bids: orderbook_snapshot
-                .bids
-                .iter()
-                .map(|x| parse_order(x))
-                .collect(),
-            snapshot,
-            json: msg.to_string(),
+        if let Some(timestamp) = timestamp {
+            vec![OrderBookMsg {
+                exchange: EXCHANGE_NAME.to_string(),
+                market_type: MarketType::Spot,
+                symbol,
+                pair,
+                msg_type: MessageType::L2Event,
+                timestamp,
+                asks: orderbook_snapshot
+                    .asks
+                    .iter()
+                    .map(|x| parse_order(x))
+                    .collect(),
+                bids: orderbook_snapshot
+                    .bids
+                    .iter()
+                    .map(|x| parse_order(x))
+                    .collect(),
+                snapshot,
+                json: msg.to_string(),
+            }]
+        } else {
+            vec![]
         }
     } else {
-        let symbol = if arr.len() == 4 {
-            debug_assert_eq!(arr[2].as_str().unwrap(), "book-25");
-            arr[3].as_str().unwrap()
-        } else if arr.len() == 5 {
-            debug_assert_eq!(arr[3].as_str().unwrap(), "book-25");
-            arr[4].as_str().unwrap()
-        } else {
-            panic!("Unknown format: {}", msg);
-        };
-        let pair = crypto_pair::normalize_pair(symbol, EXCHANGE_NAME).unwrap();
-
-        let orderbook_updates = serde_json::from_value::<OrderbookUpdate>(arr[1].clone())?;
-        let timestamp = if orderbook_updates.a.is_some() {
-            (orderbook_updates.a.clone().unwrap()[0][2]
-                .parse::<f64>()
-                .unwrap()
-                * 1000.0) as i64
-        } else if orderbook_updates.b.is_some() {
-            (orderbook_updates.b.clone().unwrap()[0][2]
-                .parse::<f64>()
-                .unwrap()
-                * 1000.0) as i64
-        } else {
-            panic!("Both a and b are empty");
-        };
-
         let mut asks: Vec<Order> = Vec::new();
         let mut bids: Vec<Order> = Vec::new();
-
-        for x in orderbook_updates.a.iter() {
-            for raw_order in x.iter() {
-                let order = parse_order(raw_order);
-                asks.push(order);
-            }
-        }
-        for x in orderbook_updates.b.iter() {
-            for raw_order in x.iter() {
-                let order = parse_order(raw_order);
-                bids.push(order);
-            }
-        }
-        if arr.len() == 5 {
-            let orderbook_updates = serde_json::from_value::<OrderbookUpdate>(arr[2].clone())?;
-            for x in orderbook_updates.a.iter() {
-                for raw_order in x.iter() {
+        let mut timestamps: Vec<i64> = Vec::new();
+        let mut process_update = |update: OrderbookUpdate| {
+            if let Some(a) = update.a {
+                for raw_order in a.iter() {
                     let order = parse_order(raw_order);
                     asks.push(order);
+                    let t = (raw_order[2].parse::<f64>().unwrap() * 1000.0) as i64;
+                    timestamps.push(t);
                 }
             }
-            for x in orderbook_updates.b.iter() {
-                for raw_order in x.iter() {
+            if let Some(b) = update.b {
+                for raw_order in b.iter() {
                     let order = parse_order(raw_order);
                     bids.push(order);
+                    let t = (raw_order[2].parse::<f64>().unwrap() * 1000.0) as i64;
+                    timestamps.push(t);
                 }
             }
-        }
+        };
+        if arr.len() == 4 {
+            let update = serde_json::from_value::<OrderbookUpdate>(arr[1].clone())?;
+            process_update(update);
+        } else if arr.len() == 5 {
+            let update = serde_json::from_value::<OrderbookUpdate>(arr[1].clone())?;
+            process_update(update);
+            let update = serde_json::from_value::<OrderbookUpdate>(arr[2].clone())?;
+            process_update(update);
+        } else {
+            panic!("Unknown message format {}", msg);
+        };
 
-        OrderBookMsg {
-            exchange: EXCHANGE_NAME.to_string(),
-            market_type: MarketType::Spot,
-            symbol: symbol.to_string(),
-            pair,
-            msg_type: MessageType::L2Event,
-            timestamp,
-            asks,
-            bids,
-            snapshot,
-            json: msg.to_string(),
+        let timestamp = if timestamps.is_empty() {
+            None
+        } else {
+            let max = *timestamps.iter().max().unwrap();
+            Some(max)
+        };
+        if let Some(timestamp) = timestamp {
+            vec![OrderBookMsg {
+                exchange: EXCHANGE_NAME.to_string(),
+                market_type: MarketType::Spot,
+                symbol,
+                pair,
+                msg_type: MessageType::L2Event,
+                timestamp,
+                asks,
+                bids,
+                snapshot,
+                json: msg.to_string(),
+            }]
+        } else {
+            vec![]
         }
     };
 
-    Ok(vec![orderbook])
+    Ok(orderbooks)
 }
