@@ -4,7 +4,7 @@ pub(super) mod binance;
 pub(super) mod bitfinex;
 pub(super) mod bitget;
 pub(super) mod bithumb;
-pub(super) mod bitmex;
+pub mod bitmex;
 pub(super) mod bitstamp;
 pub(super) mod bitz;
 pub(super) mod bybit;
